@@ -1,6 +1,6 @@
 package CPAN::Local;
 {
-  $CPAN::Local::VERSION = '0.001';
+  $CPAN::Local::VERSION = '0.002';
 }
 
 # ABSTRACT: Hack custom CPAN repos
@@ -150,6 +150,7 @@ sub _build_plugins
 
 __PACKAGE__->meta->make_immutable;
 
+
 __END__
 =pod
 
@@ -159,7 +160,60 @@ CPAN::Local - Hack custom CPAN repos
 
 =head1 VERSION
 
-version 0.001
+version 0.002
+
+=head1 DESCRIPTION
+
+CPAN::Local is a framework for creating custom CPAN implementations. The
+individual tasks related to mirror management are handled by separate plugins,
+and those plugins can be combined to achieve the desired behavior, or new
+ones can be written where further customizations is needed.
+
+This document describes the C<CPAN::Local> class, which represents a local
+repository with plugins configured to perform actions on it.
+
+=head1 ATTRIBUTES
+
+=head2 config_filename
+
+Base name of the configuration file. Default is C<cpanlocal>.
+
+=head2 config
+
+A L<Config::MVP::Sequence> representing the mirror configuration. Normally
+generated by reading the configuration file (see L</config_filename>).
+
+=head2 root_namespace
+
+The root namespaces for plugins and roles that will be loaded. Default is
+C<CPAN::Local>.
+
+=head2 distribution_base_class
+
+The base class for distribution objects. Default is
+C<CPAN::Local::Distribution>.
+
+=head2 root
+
+The root directory of the repository. Assumes the current working
+directory by default.
+
+=head2 logger
+
+Logging facility. An instance of L<Log::Dispatchouli> by default.
+
+=head2 plugins
+
+All plugins requested by the L</config>, required and instantiated.
+
+=head1 METHODS
+
+=head2 C<plugins_with($role_name)>
+
+Returns all plugins that implement a given role. Only the last portion
+of the role name should be passed as an argument - i.e. if C<$role_name>
+is C<Index>, then all plugins implementing C<CPAN::Local::Role::Indexa>
+will be returned.
 
 =head1 AUTHOR
 
