@@ -1,6 +1,6 @@
 package CPAN::Local::App::Command::update;
 {
-  $CPAN::Local::App::Command::update::VERSION = '0.001';
+  $CPAN::Local::App::Command::update::VERSION = '0.002';
 }
 
 # ABSTRACT: Update repository
@@ -43,6 +43,7 @@ sub execute
 
 __PACKAGE__->meta->make_immutable;
 
+
 __END__
 =pod
 
@@ -52,7 +53,15 @@ CPAN::Local::App::Command::update - Update repository
 
 =head1 VERSION
 
-version 0.001
+version 0.002
+
+=head1 SYNOPSIS
+
+  % lpan update
+
+=head1 DESCRIPTION
+
+Update the repository in the current directory.
 
 =head1 AUTHOR
 
