@@ -1,6 +1,6 @@
 package CPAN::Local::Plugin::Duplicates;
 {
-  $CPAN::Local::Plugin::Duplicates::VERSION = '0.001';
+  $CPAN::Local::Plugin::Duplicates::VERSION = '0.002';
 }
 
 # ABSTRACT: Remove duplicates
@@ -10,26 +10,27 @@ use warnings;
 
 use Moose;
 extends 'CPAN::Local::Plugin';
-with 'CPAN::Local::Role::Clean';
+with 'CPAN::Local::Role::Prune';
 use namespace::clean -except => 'meta';
 
-sub clean
+sub prune
 {
     my ( $self, @distros ) = @_;
 
-    my (%paths, @cleaned);
+    my (%paths, @needed);
 
     foreach my $distro ( @distros )
     {
         next if $paths{$distro->path}++;
-        push @cleaned, $distro;
+        push @needed, $distro;
     }
 
-    return @cleaned;
+    return @needed;
 }
 
 __PACKAGE__->meta->make_immutable;
 
+
 __END__
 =pod
 
@@ -39,7 +40,22 @@ CPAN::Local::Plugin::Duplicates - Remove duplicates
 
 =head1 VERSION
 
-version 0.001
+version 0.002
+
+=head1 IMPLEMENTS
+
+=over
+
+=item L<CPAN::Local::Plugin::Clean>
+
+=back
+
+=head1 METHODS
+
+=head2 clean
+
+De-dups the distribution list. A distribution is considered a duplicate if
+there is already another disribution that will write to the same path.
 
 =head1 AUTHOR
 
